Documentation
¶
Overview ¶
Package pagerank computes PageRank on up to MaxUInt32 (4,294,967,295) items via graph traversal.
The demonstration that this method is effective in calculating PageRank comes via http://arxiv.org/pdf/1006.2880.pdf
The key insight is that simple graph iteration and counting can approximate PageRank, and can also -- if the graph is stored -- be used to inexpensively recalculate PageRank when edges are added to or removed from the graph.
This package does not ultimately store the entire graph traversal history, and therefore it does not assist with recalculating PageRank when edges are removed from the graph. However, it is designed to make the addition of edges easy and inexpensive, since it stores traversal counts from prior runs. The choice to store traversal counts (rather than the full traversal history) is the reason that edge removal is not facilitated.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Base ¶
type Base struct {
// contains filtered or unexported fields
}